<?php
// +--------------------------------------------------------------------------+
// | PayPal Plugin - geeklog CMS                                             |
// +--------------------------------------------------------------------------+
// | ipnlog.php                                                               |
// |                                                                          |
// | Allows paypal administrators to view the ipnlog from the database        |
// +--------------------------------------------------------------------------+
// |                                                                          |
// | Copyright (C) 2005-2006 by the following authors:                        |
// |                                                                          |
// | Authors: Vincent Furia     - vinny01 AT users DOT sourceforge DOT net    |
// +--------------------------------------------------------------------------+
// |                                                                          |
// | This program is free software; you can redistribute it and/or            |
// | modify it under the terms of the GNU General Public License              |
// | as published by the Free Software Foundation; either version 2           |
// | of the License, or (at your option) any later version.                   |
// |                                                                          |
// | This program is distributed in the hope that it will be useful,          |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of           |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            |
// | GNU General Public License for more details.                             |
// |                                                                          |
// | You should have received a copy of the GNU General Public License        |
// | along with this program; if not, write to the Free Software Foundation,  |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.          |
// |                                                                          |
// +--------------------------------------------------------------------------+

/**
 * Allows paypal administrators to view the ipnlog from the database
 *
 * @author Vincent Furia <vinny01 AT users DOT sourceforge DOT net>
 * @copyright Vincent Furia 2005 - 2006
 * @package paypal
 */

/**
 * Required geeklog
 */
require_once('../../../lib-common.php');

// Check for required permissions
paypal_access_check('paypal.admin');

// Incoming variable filter
$vars = array('op' => 'alpha',
              'txn_id' => 'alpha',
              'id' => 'number');
paypal_filterVars($vars, $_REQUEST);

/**
 * Displays the list of ipn history from the log stored in the database
 *
 * @return string HTML string containing the contents of the ipnlog
 */
function ipnlog_list() {
    global $_TABLES, $_CONF, $LANG_PAYPAL_1;

    $display .= COM_startBlock($LANG_PAYPAL_1['ipn_history']);

    // Get ipnlog from database
    $sql = "SELECT * FROM {$_TABLES['paypal.ipnlog']} ORDER BY time DESC";
    $res = DB_query($sql);

    // Create ipnlog template
    $ipnlog = new Template($_CONF['path'] . 'plugins/paypal/templates');
    $ipnlog->set_file(array('ipnlog' => 'ipnlog_item.thtml',
                            'start'  => 'ipnlog_start.thtml',
                            'end'    => 'ipnlog_end.thtml') );
    $ipnlog->set_var('site_url', $_CONF['site_url']);
	$ipnlog->set_var('ID', $LANG_PAYPAL_1['ID']);
	$ipnlog->set_var('IP_address', $LANG_PAYPAL_1['IP_address']);
	$ipnlog->set_var('date_time', $LANG_PAYPAL_1['date_time']);
	$ipnlog->set_var('verified', $LANG_PAYPAL_1['verified']);
	$ipnlog->set_var('txn_id', $LANG_PAYPAL_1['txn_id']);
	$ipnlog->set_var('payment_status', $LANG_PAYPAL_1['payment_status']);
	$ipnlog->set_var('purchaser', $LANG_PAYPAL_1['purchaser']);

    // Display the begging of the ipnlog list
    $display .= $ipnlog->parse('output', 'start');

    // Display each ipnlog row
    while ($A = DB_fetchArray($res)) {
        $ipnlog->set_var('id', $A['id']);
        $ipnlog->set_var('ip_addr', $A['ip_addr']);
        $ipnlog->set_var('time', $A['time']);
        if ($A['verified']) {
            $ipnlog->set_var('verified', 'true');
        } else {
            $ipnlog->set_var('verified', 'false');
        }
        $ipn = unserialize($A['ipn_data']);
        $ipnlog->set_var('txn_id', $ipn['txn_id']);
        $ipnlog->set_var('status', $ipn['payment_status']);
        $ipnlog->set_var('purchaser', $ipn['custom']);
        $display .= $ipnlog->parse('output', 'ipnlog');
    }

    // Display the end of the ipnlog list
    $display .= $ipnlog->parse('output', 'end');
    $display .= COM_endBlock();
    return $display;
}

/**
 * Display a single row from the ipnlog
 *
 * Not only display the row, but beautify the serialized POST data from the transaction
 * for easy viewing.
 *
 * @param int $id Unique identifier for the row of the ipnlog to display
 * @param string $txn_id Unique identifier for the row (txn_id) of the ipnlog to display
 * @return string HTML of the ipnlog row specified by $id
 */
function ipnlog_single($id, $txn_id) {
    global $_TABLES, $_CONF;

    // Get ipnlog from database
    if ($id > 0) {
        $sql = "SELECT * FROM {$_TABLES['paypal.ipnlog']} WHERE id = $id";
    } else {
        $sql = "SELECT * FROM {$_TABLES['paypal.ipnlog']} WHERE txn_id = '$txn_id'";
    }
    $res = DB_query($sql);
    $A = DB_fetchArray($res);

    // Start Display
    $display .= COM_startBlock($LANG_PAYPAL_1['ipn_history'] . " (#{$A['id']})");

    // Create ipnlog template
    $ipnlog = new Template($_CONF['path'] . 'plugins/paypal/templates');
    $ipnlog->set_file(array('ipnlog' => 'ipnlog_detail.thtml'));
    $ipnlog->set_var('site_url', $_CONF['site_url']);
    $ipnlog->set_var('IPN_log', $LANG_PAYPAL_1['IPN_log']);
    $ipnlog->set_var('IP_address', $LANG_PAYPAL_1['IP_address']);
    $ipnlog->set_var('date_time', $LANG_PAYPAL_1['date_time']);
    $ipnlog->set_var('verified', $LANG_PAYPAL_1['verified']);
    $ipnlog->set_var('transaction', $LANG_PAYPAL_1['transaction']);
    $ipnlog->set_var('gross_payment', $LANG_PAYPAL_1['gross_payment']);
    $ipnlog->set_var('payment_status', $LANG_PAYPAL_1['payment_status']);
    $ipnlog->set_var('raw', $LANG_PAYPAL_1['raw']);	

    // Display the specified ipnlog row
    $ipnlog->set_var('id', $A['id']);
    $ipnlog->set_var('ip_addr', $A['ip_addr']);
    $ipnlog->set_var('time', $A['time']);
    if ($A['verified']) {
        $ipnlog->set_var('verified', $LANG_PAYPAL_1['true']);
    } else {
        $ipnlog->set_var('verified', $LANG_PAYPAL_1['false']);
    }

    // Allow all serialized data to be available to the template
    $ipn = unserialize($A['ipn_data']);
    foreach ($ipn as $name => $value) {
        $ipnlog->set_var($name, $value);
    }

    // Grab a raw print of the ipn data
    ob_start();
    print_r($ipn);
    $raw = ob_get_contents();
    ob_end_clean();

    // replace \n with <br>
    $raw = nl2br($raw);

    $ipnlog->set_var('raw', $raw);
    $display .= $ipnlog->parse('output', 'ipnlog');

    $display .= COM_endBlock();
    return $display;

}

// begin display of page
$display = COM_siteHeader();
$display .= paypal_admin_menu();

// base output on selected opeation (op)
switch ($_REQUEST['op']) {
    case 'single':
        $display .= ipnlog_single($_REQUEST['id'], $_REQUEST['txn_id']);
        break;

    case 'all':
    default:
        $display .= ipnlog_list();
        break;
}

$display .= COM_siteFooter();
echo $display;

?>