<?php
// +--------------------------------------------------------------------------+
// | PayPal Plugin - geeklog CMS                                             |
// +--------------------------------------------------------------------------+
// | product_edit.php                                                         |
// |                                                                          |
// | Displays a form for the editing products                                 |
// |                                                                          |
// | Allows for the altering and deletion of existing products as well as the |
// | creation of new products                                                 |
// +--------------------------------------------------------------------------+
// |                                                                          |
// | Copyright (C) 2005-2006 by the following authors:                        |
// |                                                                          |
// | Authors: Vincent Furia     - vinny01 AT users DOT sourceforge DOT net    |
// +--------------------------------------------------------------------------+
// |                                                                          |
// | This program is free software; you can redistribute it and/or            |
// | modify it under the terms of the GNU General Public License              |
// | as published by the Free Software Foundation; either version 2           |
// | of the License, or (at your option) any later version.                   |
// |                                                                          |
// | This program is distributed in the hope that it will be useful,          |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of           |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            |
// | GNU General Public License for more details.                             |
// |                                                                          |
// | You should have received a copy of the GNU General Public License        |
// | along with this program; if not, write to the Free Software Foundation,  |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.          |
// |                                                                          |
// +--------------------------------------------------------------------------+

/**
 * Displays a form for the editing products
 *
 * Allows for the altering and deletion of existing products as well as the
 * creation of new products
 *
 * @author Vincent Furia <vinny01 AT users DOT sourceforge DOT net>
 * @copyright Vincent Furia 2005 - 2006
 * @package paypal
 */

/**
 * Required geeklog
 */
require_once('../../../lib-common.php');

// Check for required permissions
paypal_access_check('paypal.admin');

// Incoming variable filter
$vars = array('op' => 'alpha',
              'id' => 'number',
              'name' => 'text',
              'category' => 'text',
              'short_description' => 'html',
              'description' => 'html',
              'price' => 'alpha',
              'small_pic' => 'alpha',
              'picture' => 'alpha',
              'download' => 'number',
              'physical' => 'number',
              'file' => 'alpha',
              'expiration' => 'number' );
paypal_filterVars($vars, $_REQUEST);

/**
 * This function creates a product Form
 *
 * Creates a Form for a product using the supplied defaults (if specified).
 *
 * @param array $product array of values describing a proudct
 * @return string HTML string of product form
 */
function getProductForm($product = array()) {
    global $_CONF, $LANG_PAYPAL_1;

    $display = COM_startBlock($LANG_PAYPAL_1['edit_label'] . ' ' . $product['name']);

    $template = new Template($_CONF['path'] . 'plugins/paypal/templates');
    $template->set_file(array('product' => 'product_form.thtml'));
    $template->set_var('site_url', $_CONF['site_url']);
    $template->set_var('name_label', $LANG_PAYPAL_1['name_label']);
    $template->set_var('category_label', $LANG_PAYPAL_1['category_label']);
	$template->set_var('short_description_label', $LANG_PAYPAL_1['short_description_label']);
	$template->set_var('description_label', $LANG_PAYPAL_1['description_label']);
	$template->set_var('price_label', $LANG_PAYPAL_1['price_label']);
	$template->set_var('small_picture_label', $LANG_PAYPAL_1['small_picture_label']);
	$template->set_var('picture_label', $LANG_PAYPAL_1['picture_label']);
	$template->set_var('downloaded_product_label', $LANG_PAYPAL_1['downloaded_product_label']);
	$template->set_var('yes', $LANG_PAYPAL_1['yes']);
	$template->set_var('no', $LANG_PAYPAL_1['no']);
	$template->set_var('shipped_product_label', $LANG_PAYPAL_1['shipped_product_label']);
	$template->set_var('filename_label', $LANG_PAYPAL_1['filename_label']);
	$template->set_var('expiration_label', $LANG_PAYPAL_1['expiration_label']);
	$template->set_var('save_button', $LANG_PAYPAL_1['save_button']);
	$template->set_var('delete_button', $LANG_PAYPAL_1['delete_button']);
	$template->set_var('ok_button', $LANG_PAYPAL_1['ok_button']);
	$template->set_var('required_field', $LANG_PAYPAL_1['required_field']);
	$template->set_var('currency', $_CONF['paypal']['currency']);

    if (is_numeric($product['id'])) {
        $template->set_var('id', '<input type="hidden" name="id" value="' . $product['id'] .'" />');
    } else {
        $template->set_var('id', '');
    }
    $template->set_var('name', $product['name']);
    $template->set_var('category', $product['category']);
    $template->set_var('short_description',
                       htmlspecialchars(str_replace('&#36;','$',$product['short_description'])));
    $template->set_var('description', $product['description']);
    $template->set_var('price', $product['price']);
    $template->set_var('small_pic', $product['small_pic']);
    $template->set_var('picture', $product['picture']);
    if ($product['download'] == 1) {
        $template->set_var('download_yes', ' selected');
        $template->set_var('download_no', '');
    } else {
        $template->set_var('download_yes', '');
        $template->set_var('download_no', ' selected');
    }
    if ($product['physical'] == 1) {
        $template->set_var('physical_yes', ' selected');
        $template->set_var('physical_no', '');
    } else {
        $template->set_var('physical_yes', '');
        $template->set_var('physical_no', ' selected');
    }
    $template->set_var('file', $product['file']);
    $template->set_var('expiration', $product['expiration']);
    $display .= $template->parse('output', 'product');

    $display .= COM_endBlock();
    return $display;
}


/**
 * main section
 */
switch ($_REQUEST['op']) {
    case 'delete':
	    DB_delete($_TABLES['paypal_products'], 'id', $_REQUEST['id']);
    if (DB_affectedRows('') == 1) {
        $msg = $LANG_PAYPAL_1['deletion_succes'];
    } else {
        $msg = $LANG_PAYPAL_1['deletion_fail'];
    }
		// delete complete, return to product list
        echo COM_refresh($_CONF['site_url'] . "/admin/plugins/paypal/index.php?msg=$msg");
        exit();
        break;

    case 'save':
        if (empty($_REQUEST['name']) || empty($_REQUEST['short_description']) ||
                !is_numeric($_REQUEST['price']) || !is_numeric($_REQUEST['download']) ) {
            $display = COM_startBlock($LANG_PAYPAL_1['error']);
            $display .= $LANG_PAYPAL_1['missing_field'];
            $display .= COM_endBlock();
            $display .= getProductForm($_REQUEST);
            break;
        }
        // prepare strings for insertion
        $_REQUEST['name'] = addslashes($_REQUEST['name']);
        $_REQUEST['category'] = addslashes($_REQUEST['category']);
        $_REQUEST['short_description'] = addslashes($_REQUEST['short_description']);
        $_REQUEST['description'] = addslashes($_REQUEST['description']);
        // price can only contain numbers and a decimal
        $_REQUEST['price'] = preg_replace('/[^\d.]/', '', $_REQUEST['price']);
        // 0 indicates no expiraton and must be stored as NULL in the DB
        if ( $_REQUEST['expiration'] == 0 ) {
            $_REQUEST['expiration'] = 'NULL';
        }
        $sql = "name = '{$_REQUEST['name']}', "
        		 . "category = '{$_REQUEST['category']}', "
             . "short_description = '{$_REQUEST['short_description']}', "
             . "description = '{$_REQUEST['description']}', "
             . "price = {$_REQUEST['price']}, "
             . "small_pic = '{$_REQUEST['small_pic']}', "
             . "picture = '{$_REQUEST['picture']}', "
             . "download = {$_REQUEST['download']}, "
             //. "physical = {$_REQUEST['physical']}, "
             . "file = '{$_REQUEST['file']}', "
             . "expiration = {$_REQUEST['expiration']}";
        if (!empty($_REQUEST['id'])) {
            $sql = "UPDATE {$_TABLES['paypal_products']} SET $sql "
                 . "WHERE id = {$_REQUEST['id']}";
        } else {
            $sql = "INSERT INTO {$_TABLES['paypal_products']} SET $sql ";
        }
        DB_query($sql);
        if (DB_error()) {
            $msg = $LANG_PAYPAL_1['save_fail'];
        } else {
            $msg = $LANG_PAYPAL_1['save_success'];
        }
        // save complete, return to product list
        echo COM_refresh($_CONF['site_url'] . "/admin/plugins/paypal/index.php?msg=$msg");
        exit();
        break;

    /* this case is currently not used... future expansion? */
    case 'preview':
        $display = getProductForm($_REQUEST);
        break;

    case 'edit':
        // Get the product to edit and display the form
        if (is_numeric($_REQUEST['id'])) {
            $sql = "SELECT * FROM {$_TABLES['paypal_products']} WHERE id = {$_REQUEST['id']}";
            $res = DB_query($sql);
            $A = DB_fetchArray($res);
            $display = getProductForm($A);
        } else {
            echo COM_refresh($_CONF['site_url']);
        }
        break;

    case 'new':
    default:
        $display = getProductForm();
        break;
}

$display = COM_siteHeader() . paypal_admin_menu() . $display;
$display .= COM_siteFooter();
echo $display;

?>