<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | Paypal Plugin 1.0                                                         |
// +---------------------------------------------------------------------------+
// | functions.inc                                                             |
// |                                                                           |
// | This file does two things: 1) it implements the necessary Geeklog Plugin  |
// | API methods and 2) implements all the common code needed by this plugin.  |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2009 by the following authors:                              |
// |                                                                           |
// | Authors: ::Ben - cordiste AT free DOT fr                                  |
// +---------------------------------------------------------------------------+
// | Created with the Geeklog Plugin Toolkit.                                  |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+

/**
 * paypal plugin functions.inc file
 *
 * @author Vincent Furia <vinny01 AT users DOT sourceforge DOT net>
 * @copyright Vincent Furia 2005 - 2006
 * @package paypal
 */

if (strpos(strtolower($_SERVER['PHP_SELF']), 'functions.inc') !== false) {
    die ('This file can not be used on its own.');
}

/**
 * Include paypal config file
 */
require_once ($_CONF['path'] . 'plugins/paypal/config.php');



/**
 * Throw in uid = 1 for anonymous users
 */
if ( empty($_USER['uid']) ) {
    $_USER['uid'] = 1;
    $_USER['username'] = 'anonymous';
    $_USER['fullname'] = 'Anonymous';
}

/**
 * Language file include
 */
$plugin_path = $_CONF['path'] . 'plugins/paypal/';
$langfile = $plugin_path . 'language/' . $_CONF['language'] . '.php';

if (file_exists($langfile)) {
    require_once $langfile;
} else {
    require_once $plugin_path . 'language/english.php';
}

/**
 * Paypal plugin table(s)
 */
$_DB_paypal_table_prefix = 'paypal_';
$_TABLES['paypal_ipnlog'] = $_DB_table_prefix . $_DB_paypal_table_prefix . 'ipnlog';
$_TABLES['paypal_products'] = $_DB_table_prefix . $_DB_paypal_table_prefix . 'products';
$_TABLES['paypal_downloads'] = $_DB_table_prefix . $_DB_paypal_table_prefix . 'downloads';
$_TABLES['paypal_purchases'] = $_DB_table_prefix . $_DB_paypal_table_prefix . 'purchases';


// +---------------------------------------------------------------------------+
// | Geeklog Plugin API Implementation                                         |
// +---------------------------------------------------------------------------+

/**
* Returns the item(s) for this plugin that should appear on the main menu
*
* NOTE: this MUST return the url/value pairs in the following format
* $<arrayname>[<label>] = <url>
*
* @return   mixed   menu entry, or boolean false if disabled / hidden
*
*/
function plugin_getmenuitems_paypal()
{
    global $_CONF, $LANG_PAYPAL_1;

    $menuitems = array();
  	if ($_CONF['paypal']['menuitem']) {
      	$menuitems[$_CONF['paypal']['menulabel']] = $_CONF['site_url'] . '/paypal/index.php';
    }
    return $menuitems;
}



/**
* Implements a [paypal:] autotag.
*
* @param    string  $op         operation to perform
* @param    string  $content    item (e.g. story text), including the autotag
* @param    array   $autotag    parameters used in the autotag
* @param    mixed               tag names (for $op='tagname') or formatted content
*
*/

function plugin_autotags_paypal($op, $content = '', $autotag = '')
{
    global $_CONF, $_TABLES, $LANG_PAYPAL_1;

    if ($op == 'tagname') {
        return 'paypal';
    } elseif ($op == 'parse') {
        $pid = COM_applyFilter($autotag['parm1']);
        if (! empty($pid)) {
            $url = $_CONF['site_url'] . '/paypal/product_detail.php?product=' . $pid;
            if (empty($autotag['parm2'])) {
                $linktext = 'Paypal'; // or get title from db
            } else {
                $linktext = $autotag['parm2'];
            }
            $link = COM_createLink($linktext, $url);
            $content = str_replace($autotag['tagstr'], $link, $content);
        }

        return $content;
    }
}


/**
* Return plugin entry for "Command and Control" (moderation.php)
*
* @return  array  Array containing (plugin name, admin url, url of plugin icon)
*/

function plugin_cclabel_paypal()
{
    global $_CONF, $LANG_PAYPAL_1;

    $retval = array();
    if (SEC_hasRights('paypal.admin')) {
        $retval = array($LANG_PAYPAL_1['plugin_name'],
            $_CONF['site_admin_url'] . '/plugins/paypal/index.php',
            plugin_geticon_paypal());
    }

    return $retval;
}

/**
* Return plugin entry for the Admins Only block
*
* @return array Array containing (plugin name, plugin admin url, # of plugin items or '')
*/
function plugin_getadminoption_paypal()
{
    global $_CONF, $LANG_PAYPAL_1;

    if (SEC_hasRights('paypal.admin')) {
        return array($LANG_PAYPAL_1['plugin_name'],
            $_CONF['site_admin_url'] . '/plugins/paypal/index.php', 0);
    }
}

/**
* Returns the URL of the plugin's icon
*
* @return   string      URL of the icon
*
*/
function plugin_geticon_paypal()
{
    global $_CONF;

    // popular alternative location:
    // return $_CONF['site_url'] . '/paypal/images/paypal.png';

    return $_CONF['site_admin_url'] . '/plugins/paypal/images/paypal.png';
}

/**
 * Returns the current plugin code version
 *
 * @return string    plugin version
 */
function plugin_chkVersion_paypal()
{
    global $_CONF;

    require_once $_CONF['path'] . 'plugins/paypal/autoinstall.php';

    $inst_parms = plugin_autoinstall_paypal('paypal');

    return $inst_parms['info']['pi_version'];
}

/**
* Update the plugin
*
* @return   int     Number of message to display or true for success
*
*/
function plugin_upgrade_paypal()
{
    global $_CONF, $_TABLES;

    $installed_version = DB_getItem($_TABLES['plugins'], 'pi_version',
                                    "pi_name = 'paypal'");
    $code_version = plugin_chkVersion_paypal();
    if ($installed_version == $code_version) {
        // nothing to do
        return true;
    }

    require_once $_CONF['path'] . 'plugins/paypal/autoinstall.php';

    if (! plugin_compatible_with_this_version_paypal('paypal')) {
        return 3002;
    }

    // other update code goes here
	$currentVersion = $code_version;
    switch( $currentVersion ) {
        case "0.2" :
            //Do nothing

        default :
            DB_query("UPDATE {$_TABLES['plugins']} SET pi_homepage='http://geeklog.fr' WHERE pi_name='paypal",1);
            break;
    }
    // update plugin version number
    $inst_parms = plugin_autoinstall_paypal('paypal');
    $pi_gl_version = $inst_parms['info']['pi_gl_version'];

    DB_query("UPDATE {$_TABLES['plugins']} SET pi_version = '$code_version', pi_gl_version = '$pi_gl_version' WHERE pi_name = 'paypal'");

    return true;
}

/**
* Automatic uninstall function for plugins
*
* This code is automatically uninstalling the plugin.
* It passes an array to the core code function that removes
* tables, groups, features and php blocks from the tables.
* Additionally, this code can perform special actions that cannot be
* foreseen by the core code (interactions with other plugins for example)
*
* @return   array   Plugin information
*
*/
function plugin_autouninstall_paypal()
{
    $out = array (
        /* give the name of the tables, without $_TABLES[] */
        'tables' => array('paypal_ipnlog','paypal_products','paypal_purchases'), 
        /* give the full name of the group, as in the db */
        'groups' => array('Paypal Admin', 'Paypal User', 'Paypal Viewer'),
        /* give the full name of the feature, as in the db */
        'features' => array('paypal.admin', 'paypal.user', 'paypal.view'),
        /* give the full name of the block, including 'phpblock_', etc */
        'php_blocks' => array(),
        /* give all vars with their name */
        'vars' => array()
    );

    return $out;
}

/**
 * Checks to see if the user has sufficient rights to view the page
 *
 * Check if the current user has rights (at least one of) specified by $rights.  If not log the
 * error, display a generic access denied message and exit.
 *
 * @param $rights string comma seperated list of allowable rights
 */
function paypal_access_check($rights = 'paypal.user,paypal.admin,paypal.view') {
    global $_USER, $_SERVER;

    // Confirm that the user has sufficient rights to access this page
    if (!SEC_hasRights($rights, 'OR')) {
        $display .= COM_siteHeader();
        $display .= COM_startBlock($LANG_PAYPAL_1['access_denied']);
        $display .= $LANG_PAYPAL_1['access_denied_message'];
        $display .= COM_endBlock();
        $display .= COM_siteFooter();
        COM_accessLog("Unauthorized user {$_USER['username']} from IP {$_SERVER['REMOTE_ADDR']} "
                    . 'attempted to access the paypal plugin at ' . $_SERVER['REQUEST_URI']);
        echo $display;
        exit;
    }
}

/**
 * Returns viewer menu display
 *
 * Generates the viewer menu from the template and returns the result as a string of HTML
 *
 * @return string HTML of viewer menu
 */
function paypal_viewer_menu() {
    global $_CONF, $LANG_PAYPAL_1;

    $display = COM_startBlock($LANG_PAYPAL_1['menu_label']);

    // generate the menu from the template
    $menu = new Template($_CONF['path'] . 'plugins/paypal/templates');
    $menu->set_file(array('menu' => 'viewer_menu.thtml'));
    $menu->set_var('site_url', $_CONF['site_url']);
    $menu->set_var('homepage_label', $LANG_PAYPAL_1['homepage_label']);
    $menu->set_var('product_list_label', $LANG_PAYPAL_1['product_list_label']);
    $display .= $menu->parse('output', 'menu');

    $display .= COM_endBlock();

    // return results
    return $display;
}

/**
 * Returns user menu display
 *
 * Generates the user menu from the template and returns the result as a string of HTML
 *
 * @return string HTML of user menu
 */
function paypal_user_menu() {
    global $_CONF, $LANG_PAYPAL_1;

    $display = COM_startBlock($LANG_PAYPAL_1['menu_label']);

    // generate the menu from the template
    $menu = new Template($_CONF['path'] . 'plugins/paypal/templates');
    $menu->set_file(array('menu' => 'user_menu.thtml'));
    $menu->set_var('site_url', $_CONF['site_url']);
    $menu->set_var('homepage_label', $LANG_PAYPAL_1['homepage_label']);
    $menu->set_var('product_list_label', $LANG_PAYPAL_1['product_list_label']);
    $menu->set_var('purchase_history', $LANG_PAYPAL_1['purchase_history']);
    $menu->set_var('view_cart', $LANG_PAYPAL_1['view_cart']);
    $menu->set_var('paypal_url', 'https://' . $_CONF['paypal']['paypalURL']);
    $menu->set_var('business', $_CONF['paypal']['receiverEmailAddr'][0]);
    $display .= $menu->parse('output', 'menu');

    $display .= COM_endBlock();

    // return results
    return $display;
}

/**
 * Returns admin menu display
 *
 * Generates the admin menu from the template and returns the result as a string of HTML
 *
 * @return string HTML of admin menu
 * @todo add support for pending (physical) transaction, not fully implemented
 */
function paypal_admin_menu() {
    global $_CONF, $_TABLES, $LANG_PAYPAL_1;

    $display = COM_startBlock($LANG_PAYPAL_1['menu_label']);

    // generate the menu from the template
    $menu = new Template($_CONF['path'] . 'plugins/paypal/templates');
    $menu->set_file(array('menu' => 'admin_menu.thtml'));
    $menu->set_var('site_url', $_CONF['site_url']);
    $menu->set_var('homepage_label', $LANG_PAYPAL_1['homepage_label']);
    $menu->set_var('store', $LANG_PAYPAL_1['store']);
    $menu->set_var('product_list_label', $LANG_PAYPAL_1['product_list_label']);
    $menu->set_var('new_product', $LANG_PAYPAL_1['new_product']);
    $menu->set_var('purchase_history', $LANG_PAYPAL_1['purchase_history']);
    $menu->set_var('view_IPN_log', $LANG_PAYPAL_1['view_IPN_log']);
    /**
     * @todo add support for pending transaction, not fully implemented
     */
    //$cnt = DB_count($_TABLES['paypal.purchases'], 'status', 'pending');
    //if ( $cnt <= 0 ) {
    //    $menu->set_var('pending', 'style="display: none" ');
    //} else {
    //    $menu->set_var('pending', '');
    //}

    $display .= $menu->parse('output', 'menu');

    $display .= COM_endBlock();

    // return results
    return $display;
}

/**
 * Filters submitted variables
 *
 * Uses geeklog functions to filter submitted variables for illegal content.  Any editing is
 * done in place and no value is returned
 *
 * @param array $vars associative array of variable name => type (type in (number,alpha,text,html))
 * @param array &$arr reference to associative array of variable name => value
 */
function paypal_filterVars($vars, &$arr) {
    // cycle through each variable applying the appropriate filter
    foreach ($vars as $var => $type) {
        switch ($type) {
            case 'number':
                $arr[$var] = COM_applyFilter($arr[$var], true);
                break;

            case 'html':
                $arr[$var] = COM_checkHTML($arr[$var], 'paypal.admin');
                break;

            case 'text':
                $arr[$var] = htmlspecialchars(strip_tags(COM_stripslashes($arr[$var])));
                break;

            case 'alpha':
            default:
                $arr[$var] = COM_applyFilter($arr[$var], false);
                break;
        }
    }
}

/**
 * Send out an email with (possibly) an attachment
 *
 * This function is needed because geeklog's built in mail function does not allow adding
 * attachments to outgoing email, this function does exactly that
 *
 * @param  to           string   recipients name and email address
 * @param  subject      string   subject of the email
 * @param  message_text string   the text of the email
 * @param  attachments  array    array of file names (path included), to attach
 * @param  from         string   (optional) sender of the the email
 * @param  html         bool     true if to be sent as an HTML email
 * @return boolean               true if successful,  otherwise false
 */
function paypal_mailAttachment($to, $subject, $message_text, $attachments = array(),
                               $from = '', $html = false) {
    global $_CONF, $LANG_CHARSET;

    static $mailobj;

    include_once( 'Mail.php' );
    include_once( 'Mail/RFC822.php' );

    $method = $_CONF['mail_settings']['backend'];

    if( !isset( $mailobj )) {
        if(( $method == 'sendmail' ) || ( $method == 'smtp' )) {
            $mailobj =& Mail::factory( $method, $_CONF['mail_settings'] );
        } else {
            $method = 'mail';
            $mailobj =& Mail::factory( $method );
        }
    }

    if( empty( $LANG_CHARSET )) {
        $charset = $_CONF['default_charset'];
        if( empty( $charset )) {
            $charset = 'iso-8859-1';
        }
    } else {
        $charset = $LANG_CHARSET;
    }

    if( empty( $from )) {
        $from = COM_formatEmailAddress( $_CONF['site_name'], $_CONF['site_mail']);
    }

    $headers = array();

    $headers['From'] = $from;
    if( $method != 'mail' ) {
        $headers['To'] = $to;
    }
    $headers['Date'] = date( 'r' ); // RFC822 formatted date
    if( $method == 'smtp' ) {
        list( $usec, $sec ) = explode( ' ', microtime());
        $m = substr( $usec, 2, 5 );
        $headers['Message-Id'] = '<' .  date( 'YmdHis' ) . '.' . $m
                               . '@' . $_CONF['mail_settings']['host'] . '>';
    }
    $headers['Subject'] = $subject;
    $headers['X-Mailer'] = 'geeklog ' . VERSION;

    if (count($attachments) <= 0) {
        if( $html ) {
            $headers['Content-Type'] = 'text/html; charset=' . $charset;
            $headers['Content-Transfer-Encoding'] = '8bit';
        } else {
            $headers['Content-Type'] = 'text/plain; charset=' . $charset;
        }
        $message = $message_text;
    } else {
        // Create MIME Boundary, set MIME relevant headers
        $mime_boundary = '==Mulipart_Boundary_x' . md5(time());
        $headers['MIME-Version'] = '1.0';
        $headers['Content-Type'] = "multipart/mixed;\n  boundary=\"$mime_boundary\"";

        // Create the message part of the message
        $message = "This is a multi-part message in MIME format.\n\n"
                 . "--$mime_boundary\n";
        if( $html ) {
            $message .= "Content-Type:text/html; charset=i\"$charset\"\n";
            $message .= "Content-Transfer-Encoding: 8bit\n\n";
        } else {
            $message .= "Content-Type:text/plain; charset=i\"$charset\"\n";
            $message .= "Content-Transfer-Encoding: 7bit\n\n";
        }
        $message .= $message_text . "\n\n";

        // Add attachments
        foreach ($attachments as $file) {
            // get file
            $fileh = fopen($file,'rb');
            $data  = fread($fileh,filesize($file));
            fclose($fileh);
            $filename = basename($file);

            // encode data
            $data = chunk_split(base64_encode($data));

            // Add attachment to message
            $message .= "--$mime_boundary\n" . "Content-Type: application/octet-stream;\n"
                      . "Content-Disposition: attachment;\n  filename=\"$filename\"\n"
                      . "Content-Transfer-Encoding: base64\n\n" . $data . "\n\n";
        }

        $message .= "--$mime_boundary--\n";
    }

    $retval = $mailobj->send( $to, $headers, $message );
    if( $retval !== true ) {
        COM_errorLog( $retval->toString(), 1 );
    }

    return( $retval === true ? true : false );
}

/**
 * Manually generate different types of buttons
 *
 * @param string $type Type of button to generate (donation, subscribe, buy_now, add_to_cart)
 * @param array  $vars Associative array of input variables, contents depend on type of button,
 *                     include: (name, id, price, business, user_id, count, type)
 * @return string      HTML of requested button
 */
function paypal_genButton($type, $vars) {
    global $_CONF, $_USER;

    // must be an expected type
    if ( $type != 'donation' && $type != 'subscribe' &&
         $type != 'buy_now' && $type != 'add_to_cart' ) {
        return false;
    }

    $button = new Template($_CONF['path'] . 'plugins/paypal/templates');
    $button->set_file(array('button'   => "{$type}_button.thtml"));

    $button->set_var('site_url', $_CONF['site_url']);
    $button->set_var('paypal_url', 'https://' . $_CONF['paypal']['paypalURL']);

    if (empty($vars['user_id'])) {
        $button->set_var('user_id', $_USER['uid']);
    } else {
        $button->set_var('user_id', $vars['user_id']);
    }
    if (empty($vars['business'])) {
        $button->set_var('business', $_CONF['paypal']['receiverEmailAddr'][0]);
    } else {
        $button->set_var('business', $vars['business']);
    }

    $button->set_var('id', $vars['id']);
    $button->set_var('name', $vars['name']);
    $button->set_var('price', $vars['price']);
    $button->set_var('count', $vars['count']);
    $button->set_var('type', $vars['type']);

    return $button->parse('output', 'button');
}
?>
