<?php
// +--------------------------------------------------------------------------+
// | PayPal Plugin - geeklog CMS                                             |
// +--------------------------------------------------------------------------+
// | index.php                                                                |
// |                                                                          |
// | Index page for users of the paypal plugin                                |
// |                                                                          |
// | By default displays available products along with links to purchase      |
// | history and detailed product views                                       |
// +--------------------------------------------------------------------------+
// |                                                                          |
// | Copyright (C) 2005-2006 by the following authors:                        |
// |                                                                          |
// | Authors: Vincent Furia     - vinny01 AT users DOT sourceforge DOT net    |
// +--------------------------------------------------------------------------+
// |                                                                          |
// | This program is free software; you can redistribute it and/or            |
// | modify it under the terms of the GNU General Public License              |
// | as published by the Free Software Foundation; either version 2           |
// | of the License, or (at your option) any later version.                   |
// |                                                                          |
// | This program is distributed in the hope that it will be useful,          |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of           |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            |
// | GNU General Public License for more details.                             |
// |                                                                          |
// | You should have received a copy of the GNU General Public License        |
// | along with this program; if not, write to the Free Software Foundation,  |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.          |
// |                                                                          |
// +--------------------------------------------------------------------------+

/**
 * Index page for users of the paypal plugin
 *
 * By default displays available products along with links to purchase history
 * and detailed product views
 *
 * @author Vincent Furia <vinny01 AT users DOT sourceforge DOT net>
 * @copyright Vincent Furia 2005 - 2006
 * @package paypal
 * @todo Add more complex logic to decide link display between:  purchase, login, download
 */

/**
 * require core geeklog code
 */
require_once '../lib-common.php';

/* Ensure sufficient privs to read this page */
paypal_access_check('paypal.viewer');

$vars = array('msg' => 'text',
              'page' => 'number',
              'category' => 'text' );
paypal_filterVars($vars, $_REQUEST);

$display = COM_siteHeader();
if (SEC_hasRights('paypal.user', 'paypal.admin')) {
    $display .= paypal_user_menu();
} else {
    $display .= paypal_viewer_menu();
}
$display .= COM_startBlock($LANG_PAYPAL_1['products']);

// Display categories
if (isset( $_CONF['paypal']['categoryColumns']) && $_CONF['paypal']['categoryColumns'] > 0) {
    $sql = "SELECT category, count(*) count FROM {$_TABLES['paypal.products']} WHERE category IS NOT NULL AND category <> '' GROUP BY category ORDER BY category";
    	$res = DB_query($sql);
    	$nrows = DB_numRows($res);
    	if ($nrows > 0) {
    	    $cat = new Template($_CONF['path'] . 'plugins/paypal/templates');
		$cat->set_file(array('table'    => 'category_table.thtml',
							 'row'      => 'category_row.thtml',
							 'category' => 'category.thtml'));
		$cat->set_var('width', floor (100 / $_CONF['paypal']['categoryColumns']));
    		for ($i = 1; $i <= $nrows; $i++) {
    	    		$C = DB_fetchArray ($res);
					$cat->set_var('category_heading', $LANG_PAYPAL_1['category_heading']);
    	    		$cat->set_var('category_name', $C['category']);
    	    		$cat->set_var('category_link', $_CONF['site_url'] . '/paypal/index.php?category='. urlencode($C['category']));
    	    		$cat->set_var('count', $C['count']);
    	    		if ($C['category'] == $_REQUEST['category']) {
    	    		    $cat->set_var('curr', 'current');
    	    		} else {
    	    		    $cat->set_var('curr', 'other');
    	    		}
    	    		$cat->parse('catrow', 'category', true);
    	    		if ($i % $_CONF['paypal']['categoryColumns'] == 0) {
    	    			$cat->parse('categories', 'row', true);
    	    			$cat->set_var('catrow', '');
    	    		}
	    	}
	    	if ($nrows % $_CONF['paypal']['categoryColumns'] != 0) {
    	    		$cat->parse('categories', 'row', true);
    	    }
	    	$display .= $cat->parse('', 'table');
    	}
}

// Get products from database
$sql = "SELECT id,name,short_description,price,small_pic,download FROM {$_TABLES['paypal.products']}";

// If applicable, limit by category
if (isset( $_CONF['paypal']['categoryColumns']) && $_CONF['paypal']['categoryColumns'] > 0 &&
	!empty($_REQUEST['category']) ) {
	$sql .= " WHERE category = '{$_REQUEST['category']}'";
}

// If applicable, order by
if (!empty($_CONF['paypal']['order'])) {
	$sql .= " ORDER BY {$_CONF['paypal']['order']}";
}

// If applicable, handle pagination of query
if (isset($_CONF['paypal']['maxPerPage']) && $_CONF['paypal']['maxPerPage'] > 0) {
    // Count products from database
    $count = DB_count($_TABLES['paypal.products']);
    // Make sure page count is reasonable, if not, fix it
    if ($_REQUEST['page'] <= 0) {
        $_REQUEST['page'] = 1;
    }
    if ((($_REQUEST['page']-1) * $_CONF['paypal']['maxPerPage']) > $count) {
        $_REQUEST['page'] = ceil($count / $_CONF['paypal']['maxPerPage']);
    }
    // Add limit for pagination (if applicable)
    if ($count > $_CONF['paypal']['maxPerPage']) {
        $sql .= ' LIMIT ' . ($_REQUEST['page']-1) * $_CONF['paypal']['maxPerPage'] . ', ' . $_CONF['paypal']['maxPerPage'];
    }
}

// query
$res = DB_query($sql);

// Create product template
$product = new Template($_CONF['path'] . 'plugins/paypal/templates');
$product->set_file(array('start'   => 'product_list_start.thtml',
                         'end'     => 'product_list_end.thtml',
                         'product' => 'product_list_item.thtml',
                         'buy'     => 'buy_now_button.thtml',
                         'cart'    => 'add_to_cart_button.thtml'));
$product->set_var('edit', '');
$product->set_var('site_url', $_CONF['site_url']);
$product->set_var('paypal_url', 'https://' . $_CONF['paypal']['paypalURL']);
$product->set_var('user_id', $_USER['uid']);
$product->set_var('business', $_CONF['paypal']['receiverEmailAddr'][0]);
$product->set_var('price_label', $LANG_PAYPAL_1['price_label']);
$product->set_var('currency', $_CONF['paypal']['currency']);

if (!empty($_REQUEST['category'])) {
    	$product->set_var('title', $_REQUEST['category']);
} else {
	$product->set_var('title', $LANG_PAYPAL_1['featured_products']);
}
$display .= $product->parse('', 'start');

// Display each product
while ($A = DB_fetchArray($res)) {
    $product->set_var('id', $A['id']);
    $product->set_var('name', $A['name']);
    $product->set_var('short_description', PLG_replacetags($A['short_description']));
    $product->set_var('price', $A['price']);
    if (empty($A['small_pic'])) {
    	$product->set_var('display', '');
    	$product->set_var('small_pic', $_CONF['site_url'] . '/paypal/images/default.png');
    } else {
    	$product->set_var('display', '');
    	$product->set_var('small_pic', $A['small_pic']);
	}
    // FIXME: If a user purchased once with no expiration, this query will not operate correctly
    $time = DB_getItem($_TABLES['paypal.purchases'], 'MAX(UNIX_TIMESTAMP(expiration))',
                       "user_id = {$_USER['uid']} AND product_id = {$A['id']}");
    // Setup purchase links. If anonymous, ask for login. If free or purchased display
    // download link
    /* For anymous users, login */
    if ( ($A['price'] > 0) && ($_USER['uid'] == 1) && (!$_CONF['paypal']['anonymous_buy'])) {
        $loginlink = $_CONF['site_url'] . '/users.php';
        $createlink = $_CONF['site_url'] . '/users.php?mode=new';
        $product->set_var('buy_now', "<a href=\"$loginlink\">" . $LANG_PAYPAL_1['login'] ."</a> or <a href=\"$createlink\">"
                                   . $LANG_PAYPAL_1['create_account'] . "</a> " . $LANG_PAYPAL_1['to_purchase']);
        $product->set_var('add2cart', '');
    /* Free items or items purchases and not expired, download */
    } else if ( $A['download'] > 0 && ( $A['price'] == 0 || $time > time() ) ) {
        $product->set_var('buy_now', "<a href=\"{$_CONF['site_url']}/paypal/download.php"
                                   . "?id={$A['id']}\">". $LANG_PAYPAL_1['Download'] . "</a>");
        $product->set_var('add2cart', '');
    /* buttons for everyone else */
    } else {
	    if (SEC_hasRights('paypal.admin')) {
	    $product->set_var('edit', "<form action=\"{$_CONF['site_url']}/admin/plugins/paypal/product_edit.php\" method=\"POST\"><div style=\"float:right\"> <input type=\"image\" src=\"{$_CONF['site_url']}/paypal/images/edit.png\" name=\"id\" value=\"{$A['id']}\" align=\"absmiddle\" /></div><input type=\"hidden\" name=\"op\" value=\"edit\" /></form>");
		}
		$product->set_var('buy_now_button', $LANG_PAYPAL_1['buy_now_button']);
    	$product->set_var('buy_now', $product->parse('', 'buy'));
		$product->set_var('add_to_cart', $LANG_PAYPAL_1['add_to_cart']);
        $product->set_var('add2cart', $product->parse('', 'cart'));
    }
    $display .= $product->parse('', 'product');
}

// Display pagination
if ((isset($_CONF['paypal']['maxPerPage'])) && ($_CONF['paypal']['maxPerPage'] > 0) &&
        ($count > $_CONF['paypal']['maxPerPage'])) {
    $product->set_var('pagination', COM_printPageNavigation($_CONF['site_url'] . '/paypal/index.php',
                                                            $_REQUEST['page'], ceil($count / $_CONF['paypal']['maxPerPage'])));
} else {
    $product->set_var('pagination', '');
}

$display .= $product->parse('', 'end');
$display .= COM_endBlock();

$display .= COM_siteFooter();
echo $display;

?>