<?php
// +--------------------------------------------------------------------------+
// | PayPal Plugin - geeklog CMS                                             |
// +--------------------------------------------------------------------------+
// | purchase_history.php                                                     |
// |                                                                          |
// | Purchase History View.  Displays the current user's history of purchases.|
// +--------------------------------------------------------------------------+
// |                                                                          |
// | Copyright (C) 2005-2006 by the following authors:                        |
// |                                                                          |
// | Authors: Vincent Furia     - vinny01 AT users DOT sourceforge DOT net    |
// +--------------------------------------------------------------------------+
// |                                                                          |
// | This program is free software; you can redistribute it and/or            |
// | modify it under the terms of the GNU General Public License              |
// | as published by the Free Software Foundation; either version 2           |
// | of the License, or (at your option) any later version.                   |
// |                                                                          |
// | This program is distributed in the hope that it will be useful,          |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of           |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            |
// | GNU General Public License for more details.                             |
// |                                                                          |
// | You should have received a copy of the GNU General Public License        |
// | along with this program; if not, write to the Free Software Foundation,  |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.          |
// |                                                                          |
// +--------------------------------------------------------------------------+

/**
 * Purchase History View.  Displays the current user's history of purchases.
 *
 * @author Vincent Furia <vinny01 AT users DOT sourceforge DOT net>
 * @copyright Vincent Furia 2005 - 2006
 * @package paypal
 */

/**
 * require core geeklog code
 */
require_once '../lib-common.php';

/* Ensure sufficient privs to read this page */
//paypal_access_check();

/* Purchase history for anonymous users/paypal viewers doesn't make sense */
if (!SEC_hasRights('paypal.user','paypal.admin','OR') || empty($_USER['uid']) ||
        ($_USER['uid'] == 1) ) {
    $display = COM_siteHeader();
    $display .= paypal_viewer_menu();
    $display .= COM_startBlock($LANG_PAYPAL_1['no_purchase_history']);
    $display .= $LANG_PAYPAL_1['access_to_purchasers'];
    $display .= COM_endBlock();
    $display .= COM_siteFooter();
    echo $display;
    exit;
}

$sql = "SELECT p.*, UNIX_TIMESTAMP(p.expiration) as time, "
     . "d.name, d.short_description, d.file, d.download "
     . "FROM {$_TABLES['paypal.purchases']} as p, {$_TABLES['paypal.products']} as d "
     . "WHERE d.id = p.product_id AND p.user_id = {$_USER['uid']} "
     . "ORDER by p.purchase_date DESC";
$res = DB_query($sql);

$display = COM_siteHeader();
$display .= paypal_user_menu();

$display .= COM_startBlock($LANG_PAYPAL_1['purchase_history']);

$history = new Template($_CONF['path'] . 'plugins/paypal/templates');
$history->set_file(array('item' => 'purchase_history_item.thtml',
                         'start' => 'purchase_history_start.thtml',
                         'end'   => 'purchase_history_end.thtml' ));
$history->set_var('site_url', $_CONF['site_url']);
$history->set_var('name', $LANG_PAYPAL_1['name']);
$history->set_var('quantity', $LANG_PAYPAL_1['quantity']);
$history->set_var('description', $LANG_PAYPAL_1['description']);
$history->set_var('purchase_date', $LANG_PAYPAL_1['purchase_date']);
$history->set_var('txn_id', $LANG_PAYPAL_1['txn_id']);
$history->set_var('expiration', $LANG_PAYPAL_1['expiration']);
$history->set_var('download', $LANG_PAYPAL_1['download']);

if (DB_numRows($res) > 0) {
    // Display start section of history
    $display .= $history->parse('output', 'start');

    // Output each row of the purchase history
    while ($A = DB_fetchArray($res)) {
        $history->set_var('id', $A['id']);
        $history->set_var('product_id', $A['product_id']);
        $history->set_var('name', $A['name']);
        $history->set_var('quantity', $A['quantity']);
        $history->set_var('short_description', $A['short_description']);
        if ( !empty($A['file']) && ($A['download'] > 0) &&
                (($A['time'] > time()) || empty($A['time'])) ) {
            $link = $_CONF['site_url'] . '/paypal/download.php?id=' . $A['product_id'];
            $history->set_var('link', "<a href=\"$link\">" . $LANG_PAYPAL_1['Download'] . "</a>");
        } else {
            $history->set_var('link', $LANG_PAYPAL_1['N/A']);
        }
        $history->set_var('txn_id', $A['txn_id']);
        $history->set_var('purchase_date', $A['purchase_date']);
        if ( empty($A['expiration']) ) {
            $history->set_var('expiration', $LANG_PAYPAL_1['N/A']);
        } else {
            $history->set_var('expiration', $A['expiration']);
        }
        $display .= $history->parse('output', 'item');
    }

    // display end section of history
    $display .= $history->parse('output', 'end');

    // Additional Message
    $display .= '<br>' . $LANG_PAYPAL_1['contact_admin'];
} else {
    // No purchase history message
    $display .= $LANG_PAYPAL_1['no_record'];
}

$display .= COM_endBlock();
$display .= COM_siteFooter();
echo $display;

?>